package cn.com.infosec.asn1.tsp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;

public class MessageImprint extends ASN1Encodable {
   AlgorithmIdentifier hashAlgorithm;
   byte[] hashedMessage;

   public static MessageImprint getInstance(Object o) {
      if (o != null && !(o instanceof MessageImprint)) {
         if (o instanceof ASN1Sequence) {
            return new MessageImprint((ASN1Sequence)o);
         } else {
            throw new IllegalArgumentException("Bad object in factory.");
         }
      } else {
         return (MessageImprint)o;
      }
   }

   public MessageImprint(ASN1Sequence seq) {
      this.hashAlgorithm = AlgorithmIdentifier.getInstance(seq.getObjectAt(0));
      this.hashedMessage = ASN1OctetString.getInstance(seq.getObjectAt(1)).getOctets();
   }

   public MessageImprint(AlgorithmIdentifier hashAlgorithm, byte[] hashedMessage) {
      this.hashAlgorithm = hashAlgorithm;
      this.hashedMessage = hashedMessage;
   }

   public AlgorithmIdentifier getHashAlgorithm() {
      return this.hashAlgorithm;
   }

   public byte[] getHashedMessage() {
      return this.hashedMessage;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10000.add(this.hashAlgorithm);
      var10000.add(new DEROctetString(this.hashedMessage));
      return new DERSequence(var1);
   }
}
